embassy-net-driver-channel

Crates

git

Versions

default

Flavors

RxRunner

Struct RxRunner 

pub struct RxRunner<'d> { /* private fields */ }
RX runner.

Holds the lower end of the channel for passing inbound packets up the stack.

Implementations

Source

impl RxRunner<'_>

pub async fn rx_ready(&mut self)

Wait until there is space in the inbound queue.

pub fn poll_rx_ready(&mut self, cx: &mut Context<'_>) -> Poll<()>

Poll whether there is space in the inbound queue.

pub async fn rx_buf(&mut self) -> PacketBuf

Wait for an empty buffer from the stack, to receive a packet into.

The buffer has zero length. Its capacity is the stack’s packet buffer size, which may be smaller than the MTU.

Push it back filled with rx, or drop it to give it back to the stack’s pool.

pub fn try_rx_buf(&mut self) -> Option<PacketBuf>

Get an empty buffer from the stack, if there is one right now.

See rx_buf.

pub fn poll_rx_buf(&mut self, cx: &mut Context<'_>) -> Poll<PacketBuf>

Poll for an empty buffer from the stack.

See rx_buf.

pub async fn rx(&mut self, buf: PacketBuf)

Push a received packet to the stack, waiting for space in the inbound queue.

pub fn try_rx(&mut self, buf: PacketBuf) -> Result<(), PacketBuf>

Push a received packet to the stack, if the inbound queue has space right now.

If it doesn’t, the buffer is handed back in the Err variant.