embassy-net-driver-channel

Crates

git

Versions

default

Flavors

TxRunner

Struct TxRunner 

pub struct TxRunner<'d> { /* private fields */ }
TX runner.

Holds the lower end of the channel for passing outbound packets down the stack.

Implementations

Source

impl TxRunner<'_>

pub async fn tx(&mut self) -> PacketBuf

Wait for a packet the stack wants to transmit.

pub fn try_tx(&mut self) -> Option<PacketBuf>

Get a packet the stack wants to transmit, if there is one right now.

pub fn poll_tx(&mut self, cx: &mut Context<'_>) -> Poll<PacketBuf>

Poll for a packet the stack wants to transmit.