pub struct RxRunner<'d> { /* private fields */ }Expand description
RX runner.
Holds the lower end of the channel for passing inbound packets up the stack.
Implementations
Sourceimpl RxRunner<'_>
impl RxRunner<'_>
Sourcepub fn poll_rx_ready(&mut self, cx: &mut Context<'_>) -> Poll<()>
pub fn poll_rx_ready(&mut self, cx: &mut Context<'_>) -> Poll<()>
Poll whether there is space in the inbound queue.
Sourcepub fn try_rx_buf(&mut self) -> Option<PacketBuf>
pub fn try_rx_buf(&mut self) -> Option<PacketBuf>
Get an empty buffer from the stack, if there is one right now.
See rx_buf.
Sourcepub fn poll_rx_buf(&mut self, cx: &mut Context<'_>) -> Poll<PacketBuf>
pub fn poll_rx_buf(&mut self, cx: &mut Context<'_>) -> Poll<PacketBuf>
Poll for an empty buffer from the stack.
See rx_buf.