embassy-net-driver-channel

Crates

git

Versions

default

Flavors

RxRunner

Struct RxRunner 

pub struct RxRunner<'d> { /* private fields */ }
RX runner.

Holds the lower end of the channel for passing inbound packets up the stack.

Implementations

Source

impl RxRunner<'_>

pub async fn rx_ready(&mut self)

Wait until there is space in the inbound queue.

pub fn poll_rx_ready(&mut self, cx: &mut Context<'_>) -> Poll<()>

Poll whether there is space in the inbound queue.

pub async fn rx(&mut self, buf: PacketBuf)

Push a received packet to the stack, waiting for space in the inbound queue.

pub fn try_rx(&mut self, buf: PacketBuf) -> Result<(), PacketBuf>

Push a received packet to the stack, if the inbound queue has space right now.

If it doesn’t, the buffer is handed back in the Err variant.